/*

    File: savehdr.h

    Copyright (C) 2004,2006 Christophe GRENIER <grenier@cgsecurity.org>
  
    This software is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.
  
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
  
    You should have received a copy of the GNU General Public License along
    with this program; if not, write the Free Software Foundation, Inc., 51
    Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

 */
#include "list.h"
typedef struct backup_disk t_backup_disk;
struct backup_disk
{
  struct list_head list;
  time_t my_time;
  char description[128];
  t_list_part *list_part;
};

int save_header(t_param_disk *disk_car,t_partition *partition, const int debug);
int partition_save(t_param_disk *disk_car, t_list_part *list_part, const int debug);
t_backup_disk *partition_load(const t_param_disk *disk_car, const int debug);

